Index: chrome/browser/chromeos/extensions/file_manager/file_browser_private_api.h |
diff --git a/chrome/browser/chromeos/extensions/file_manager/file_browser_private_api.h b/chrome/browser/chromeos/extensions/file_manager/file_browser_private_api.h |
index c43e1d6f7cadcbc0d4eb324a4384b45e4b2b651c..735f1c19b24a8b06857917bc8deccdeb23cc7221 100644 |
--- a/chrome/browser/chromeos/extensions/file_manager/file_browser_private_api.h |
+++ b/chrome/browser/chromeos/extensions/file_manager/file_browser_private_api.h |
@@ -497,18 +497,18 @@ class FileDialogStringsFunction : public SyncExtensionFunction { |
virtual bool RunImpl() OVERRIDE; |
}; |
// Retrieves property information for a file and returns it as a dictionary. |
// On error, returns a dictionary with the key "error" set to the error number |
// (drive::FileError). |
-class GetDriveFilePropertiesFunction : public FileBrowserFunction { |
+class GetDriveEntryPropertiesFunction : public FileBrowserFunction { |
public: |
- DECLARE_EXTENSION_FUNCTION("fileBrowserPrivate.getDriveFileProperties", |
+ DECLARE_EXTENSION_FUNCTION("fileBrowserPrivate.getDriveEntryProperties", |
FILEBROWSERPRIVATE_GETDRIVEFILEPROPERTIES) |
- GetDriveFilePropertiesFunction(); |
+ GetDriveEntryPropertiesFunction(); |
protected: |
- virtual ~GetDriveFilePropertiesFunction(); |
+ virtual ~GetDriveEntryPropertiesFunction(); |
// AsyncExtensionFunction overrides. |
virtual bool RunImpl() OVERRIDE; |
@@ -497,18 +497,18 @@ class FileDialogStringsFunction : public SyncExtensionFunction { |
virtual bool RunImpl() OVERRIDE; |
}; |
-// Retrieves property information for a file and returns it as a dictionary. |
+// Retrieves property information for an entry and returns it as a dictionary. |
// On error, returns a dictionary with the key "error" set to the error number |
// (drive::FileError). |